class hellow:
     def __init__(self,name):
        self.name = name
     def welcome(self):
          return f'welcome to my module test {self.name}'
'''
use : 

name = hellow('ishan')
print(name.welcome())

'''